|CI| |Docs|

=========
pyaerocom
=========

**Website and Documentation:** https://pyaerocom.readthedocs.io/en/latest/

**Installation:** https://pyaerocom.readthedocs.io/en/latest/install.html  

**Tutorials:** https://pyaerocom.readthedocs.io/en/latest/getstarted.html#tutorials-jupyter-notebooks

**AeroCom:** https://aerocom.met.no

**AeroVal** evaluation portal: https://aerocom-evaluation.met.no/

.. |CI| image:: https://github.com/metno/pyaerocom/workflows/CI/badge.svg
   :target: https://github.com/metno/pyaerocom/actions

.. |Docs| image:: https://readthedocs.org/projects/pyaerocom/badge/?version=latest
	 :target: https://pyaerocom.readthedocs.io/en/latest/?badge=latest
	 :alt: Documentation Status
